romberg

Function romberg 

pub fn romberg<F>(f: F, a: f64, b: f64, eps: f64, nmax: usize) -> f64
where F: Fn(f64) -> f64,
Integrate a function f from a to b using the Romberg method, stopping after either sequential estimates are less than eps or n steps have been taken.