Matrix

Struct Matrix 

pub struct Matrix {
    pub nrows: usize,
    pub ncols: usize,
    /* private fields */
}
Matrix struct.

Fields

nrows: usizencols: usize

Implementations

Source

impl Matrix

pub fn empty() -> Self

pub fn zeros(nrows: usize, ncols: usize) -> Self

Make a matrix filled with zeros.

pub fn ones(nrows: usize, ncols: usize) -> Self

Make a matrix filled with ones.

pub fn empty_size(nrows: usize, ncols: usize) -> Self

Make an empty matrix with a given size

pub fn eye(dims: usize) -> Self

Make an identity matrix with size dims.

pub fn is_square(&self) -> bool

Check whether the matrix is square.

pub fn inv(&self) -> Self

Invert the matrix.

pub fn is_symmetric(&self) -> bool

Check whether the matrix is symmetric.

pub fn close_to(&self, other: &Matrix, tol: f64) -> bool

Check whether a matrix is close to another matrix within some tolerance.

pub fn is_positive_definite(&self) -> bool

Check whether the matrix is positive definite.

pub fn forward_substitution(&self, b: &[f64]) -> Vector

Solve a matrix equation of the form Lx=b, where L is a lower triangular matrix. See the Wikipedia page.

pub fn backward_substitution(&self, b: &[f64]) -> Vector

Solve a matrix equation of the form Ux=b, where U is an upper triangular matrix. See the Wikipedia page.

pub fn cholesky(&self) -> Matrix

Return the Cholesky decomposition of the matrix. Resulting matrix is lower triangular.

pub fn lu(&self) -> (Matrix, Vec<i32>)

pub fn det(&self) -> f64

Calculates the determinant of the matrix using the LU decomposition.

pub fn lu_det(&self, piv: &[i32]) -> f64

Calculates the determinant of an LU decomposed matrix.

pub fn is_upper_triangular(&self) -> bool

Check whether the matrix is upper triangular (i.e., all the entries below the diagonal are 0).

pub fn is_lower_triangular(&self) -> bool

Check whether the matrix is lower triangular (i.e., all the entries above the diagonal are 0).

pub fn diag(&self) -> Vector

Get the diagonal elements of the matrix.

pub fn new<T>(data: T, nrows: i32, ncols: i32) -> Self
where T: Into<Vector>,

Make a new matrix with the given number of rows and columns.

pub fn shape(&self) -> [usize; 2]

Get the number of rows and columns in the matrix.

pub fn size(&self) -> usize

Get the total number of elements in the matrix.

pub fn reshape_mut(&mut self, nrows: i32, ncols: i32) -> &mut Self

Reshape the matrix in-place. A size of -1 in either the rows or the columns means that the size for that dimension will be automatically determined if possible.

pub fn reshape(&self, nrows: i32, ncols: i32) -> Self

Reshape the matrix. A size of -1 in either the rows or the columns means that the size for that dimension will be automatically determined if possible.

pub fn apply_along_row<F>(&mut self, row: usize, f: F)
where F: Fn(f64) -> f64,

Apply a closure to every element in a row. The closure should take a value and return the value to replace it with.

pub fn apply_along_col<F>(&mut self, col: usize, f: F)
where F: Fn(f64) -> f64,

Apply a closure to every element in a row.

pub fn get_row_as_vector(&self, row: usize) -> Vector

Return a copy of the row of the matrix as a Vector.

pub fn get_col_as_vector(&self, col: usize) -> Vector

Return a copy of the column of the matrix as a Vector.

pub fn sum_rows(&self) -> Vector

Sum the matrix across the rows.

pub fn sum_cols(&self) -> Vector

Sum the matrix down the columns.

pub fn inf_norm(&self) -> f64

Calculates the infinity norm of the matrix.

pub fn flat_idx(&self, idx: usize) -> f64

pub fn flat_idx_replace(&mut self, idx: usize, val: f64) -> &mut Self

pub fn t(&self) -> Self

Transpose the matrix.

pub fn t_mut(&mut self) -> &mut Self

Transpose the matrix in-place.

pub fn data(&self) -> &Vector

Return a reference to the underlying Vector holding the data.

pub fn data_mut(&mut self) -> &mut Vector

Return a mutable reference to the underlying Vector holding the data.

pub fn to_vec(self) -> Vector

Converts the matrix to a Vector.

pub fn hcat(&self, other: Self) -> Self

Horizontal concatenation of matrices. Adds other to the right of the calling matrix.

pub fn vcat(&self, other: Self) -> Self

Vertical concatenation of matrices. Adds other below the calling matrix.

pub fn hrepeat(&self, n: usize) -> Self

Repeat self horizontally. That is, make n total copies of self and horizontally concatenate them all together.

pub fn vrepeat(&self, n: usize) -> Self

Repeat self vertically. That is, make n total copies of self and vertically concatenate them all together.

Source

impl Matrix

pub fn ln(&self) -> Self

Apply the f64 operation ln element-wise to the matrix.

Source

impl Matrix

pub fn ln_1p(&self) -> Self

Apply the f64 operation ln_1p element-wise to the matrix.

Source

impl Matrix

pub fn log10(&self) -> Self

Apply the f64 operation log10 element-wise to the matrix.

Source

impl Matrix

pub fn log2(&self) -> Self

Apply the f64 operation log2 element-wise to the matrix.

Source

impl Matrix

pub fn exp(&self) -> Self

Apply the f64 operation exp element-wise to the matrix.

Source

impl Matrix

pub fn exp2(&self) -> Self

Apply the f64 operation exp2 element-wise to the matrix.

Source

impl Matrix

pub fn exp_m1(&self) -> Self

Apply the f64 operation exp_m1 element-wise to the matrix.

Source

impl Matrix

pub fn sin(&self) -> Self

Apply the f64 operation sin element-wise to the matrix.

Source

impl Matrix

pub fn cos(&self) -> Self

Apply the f64 operation cos element-wise to the matrix.

Source

impl Matrix

pub fn tan(&self) -> Self

Apply the f64 operation tan element-wise to the matrix.

Source

impl Matrix

pub fn sinh(&self) -> Self

Apply the f64 operation sinh element-wise to the matrix.

Source

impl Matrix

pub fn cosh(&self) -> Self

Apply the f64 operation cosh element-wise to the matrix.

Source

impl Matrix

pub fn tanh(&self) -> Self

Apply the f64 operation tanh element-wise to the matrix.

Source

impl Matrix

pub fn asin(&self) -> Self

Apply the f64 operation asin element-wise to the matrix.

Source

impl Matrix

pub fn acos(&self) -> Self

Apply the f64 operation acos element-wise to the matrix.

Source

impl Matrix

pub fn atan(&self) -> Self

Apply the f64 operation atan element-wise to the matrix.

Source

impl Matrix

pub fn asinh(&self) -> Self

Apply the f64 operation asinh element-wise to the matrix.

Source

impl Matrix

pub fn acosh(&self) -> Self

Apply the f64 operation acosh element-wise to the matrix.

Source

impl Matrix

pub fn atanh(&self) -> Self

Apply the f64 operation atanh element-wise to the matrix.

Source

impl Matrix

pub fn sqrt(&self) -> Self

Apply the f64 operation sqrt element-wise to the matrix.

Source

impl Matrix

pub fn cbrt(&self) -> Self

Apply the f64 operation cbrt element-wise to the matrix.

Source

impl Matrix

pub fn abs(&self) -> Self

Apply the f64 operation abs element-wise to the matrix.

Source

impl Matrix

pub fn floor(&self) -> Self

Apply the f64 operation floor element-wise to the matrix.

Source

impl Matrix

pub fn ceil(&self) -> Self

Apply the f64 operation ceil element-wise to the matrix.

Source

impl Matrix

pub fn to_radians(&self) -> Self

Apply the f64 operation to_radians element-wise to the matrix.

Source

impl Matrix

pub fn to_degrees(&self) -> Self

Apply the f64 operation to_degrees element-wise to the matrix.

Source

impl Matrix

pub fn recip(&self) -> Self

Apply the f64 operation recip element-wise to the matrix.

Source

impl Matrix

pub fn round(&self) -> Self

Apply the f64 operation round element-wise to the matrix.

Source

impl Matrix

pub fn signum(&self) -> Self

Apply the f64 operation signum element-wise to the matrix.

Source

impl Matrix

pub fn powi(&self, arg: i32) -> Self

Apply the f64 operation powi element-wise to the matrix.

Source

impl Matrix

pub fn powf(&self, arg: f64) -> Self

Apply the f64 operation powf element-wise to the matrix.

Source

impl Matrix

pub fn norm(&self) -> f64

pub fn max(&self) -> f64

pub fn mean(&self) -> f64

pub fn min(&self) -> f64

pub fn std(&self) -> f64

pub fn sum(&self) -> f64

pub fn prod(&self) -> f64

pub fn var(&self) -> f64

pub fn sample_std(&self) -> f64

pub fn sample_var(&self) -> f64