PolynomialRegressor

Struct PolynomialRegressor 

pub struct PolynomialRegressor {
    pub coef: Vec<f64>,
}
Implements a polynomial regressor.

In the case of a two coefficients, this reduces to simple linear regression, where the first parameter is the intercept, and the second is the slope.

Fields

coef: Vec<f64>

Implementations

Source

impl PolynomialRegressor

pub fn new(deg: usize) -> Self

Create a new polynomial regressor with degree deg (e.g., deg = 1 is a linear model).

pub fn predict(&self, x: &[f64]) -> Vec<f64>

Returns c0 + c[1] * x + c[2] * x^2 ... + cn + x^n, where c[i] are the coefficients of the polynomial regressor, and x is some vector of explanatory variables. Evaluation is done using Horner’s method.

pub fn fit(&mut self, x: &[f64], y: &[f64]) -> &mut Self

Fit the polynomial regressor to some observed data y given some explanatory variables x. Uses least squares fitting.