pub struct PolynomialRegressor {
pub coef: Vec<f64>,
}Expand description
Implements a polynomial regressor.
In the case of a two coefficients, this reduces to simple linear regression, where the first parameter is the intercept, and the second is the slope.
Fields
coef: Vec<f64>Implementations
Sourceimpl PolynomialRegressor
impl PolynomialRegressor
Sourcepub fn new(deg: usize) -> Self
pub fn new(deg: usize) -> Self
Create a new polynomial regressor with degree deg (e.g., deg = 1 is a linear model).